scipy.weave.ext_tools
=====================

.. automodule:: scipy.weave.ext_tools

   
   
   .. rubric:: Functions

   .. autosummary::
   
      assign_variable_types
      downcast
      format_error_msg
      generate_file_name
      generate_module
      indent
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
   
      ext_function
      ext_function_from_specs
      ext_module
   
   

   
   
   